pub struct ConnectedClient {
pub stream: TcpStream,
}Expand description
Represents a client that has established a connection to the server but is not yet authenticated.
Fields
stream: TcpStreamThe TCP stream representing the connection to the server.
Implementations
Sourceimpl ConnectedClient
impl ConnectedClient
Sourcepub async fn authenticate(
self,
username: String,
password: String,
key: [u8; 32],
) -> Result<AuthenticatedClient, Error>
pub async fn authenticate( self, username: String, password: String, key: [u8; 32], ) -> Result<AuthenticatedClient, Error>
Authenticates the connected client with a username and password.
Arguments
username- The username as a String.password- The password as a String.
Returns
Result<AuthenticatedClient, Error>- If successful, returns an instance of AuthenticatedClient. Otherwise, returns an Error indicating what went wrong.
Example
let unconnected_client = UnconnectedClient;
let connected_client = unconnected_client.connect("127.0.0.1:12345").await?;
let authenticated_client = connected_client.authenticate("username".to_string(), "password".to_string()).await?;Trait Implementations