pub struct AuthenticatedClient {
pub read: OwnedReadHalf,
pub write: OwnedWriteHalf,
pub key: [u8; 32],
}Expand description
Represents a client that has been authenticated.
Fields
read: OwnedReadHalfThe read half of the TCP stream.
write: OwnedWriteHalfThe write half of the TCP stream.
key: [u8; 32]Implementations
Sourceimpl AuthenticatedClient
impl AuthenticatedClient
Sourcepub fn is_alive(&self) -> bool
pub fn is_alive(&self) -> bool
Checks if the client connection is alive.
Returns
bool-trueif the connection is alive,falseotherwise.
Sourcepub async fn terminate_connection(&mut self) -> Result<(), Error>
pub async fn terminate_connection(&mut self) -> Result<(), Error>
Terminates the connection of the client.
Sourcepub async fn insert(
&mut self,
collection: String,
data: Vec<u8>,
associated_data: Vec<u8>,
acl: Vec<String>,
usecases: Vec<String>,
) -> Result<String, Error>
pub async fn insert( &mut self, collection: String, data: Vec<u8>, associated_data: Vec<u8>, acl: Vec<String>, usecases: Vec<String>, ) -> Result<String, Error>
Inserts data into a specified collection.
Arguments
collection- The name of the collection to insert the data into.data- The data to be inserted.associated_data- The associated data to be verified.acl- The access control list.usecases- The use cases associated with the data.
Sourcepub async fn insert_ope(
&mut self,
number_to_encrypt: f64,
acl: Vec<String>,
usecases: Vec<String>,
collection: String,
) -> Result<String, Error>
pub async fn insert_ope( &mut self, number_to_encrypt: f64, acl: Vec<String>, usecases: Vec<String>, collection: String, ) -> Result<String, Error>
Inserts a number into the database with Order Preserving Encryption (OPE).
Arguments
number_to_encrypt- The number to be encrypted and inserted.acl- The access control list.usecases- The use cases associated with the data.collection- The name of the collection to insert the data into.
Sourcepub async fn query(&mut self, query: Query) -> Result<QueryResult, Error>
pub async fn query(&mut self, query: Query) -> Result<QueryResult, Error>
Queries the database and returns the results.
Arguments
query- The query object representing the database query.
Sourcepub async fn modify(
&mut self,
id: String,
collection: String,
new_value: Vec<u8>,
) -> Result<Message, Error>
pub async fn modify( &mut self, id: String, collection: String, new_value: Vec<u8>, ) -> Result<Message, Error>
Modifies an existing document in the database.
Arguments
id- The identifier of the document to be modified.collection- The name of the collection containing the document.new_value- The new value to be set in the document.